summaryrefslogtreecommitdiffstats
path: root/sys/amd64
diff options
context:
space:
mode:
authorjoerg <joerg@FreeBSD.org>1997-09-13 16:12:15 +0000
committerjoerg <joerg@FreeBSD.org>1997-09-13 16:12:15 +0000
commit5167b81f672ae518842429441f38bf4c0ec9ac75 (patch)
tree0fba6b72566fd9404d52c8c4c6af31d58d010f58 /sys/amd64
parentfde8a8ec465bddd8378394c44e3b889d741f5009 (diff)
downloadFreeBSD-src-5167b81f672ae518842429441f38bf4c0ec9ac75.zip
FreeBSD-src-5167b81f672ae518842429441f38bf4c0ec9ac75.tar.gz
Revert the logic behind my last change, and use a function called
`is_physical_memory()' now for the decision whether to dump some region of memory or not. Suggested by: davidg
Diffstat (limited to 'sys/amd64')
-rw-r--r--sys/amd64/amd64/vm_machdep.c10
-rw-r--r--sys/amd64/include/md_var.h4
2 files changed, 7 insertions, 7 deletions
diff --git a/sys/amd64/include/md_var.h b/sys/amd64/include/md_var.h
index 086704a..fb6f3ad 100644
--- a/sys/amd64/include/md_var.h
+++ b/sys/amd64/include/md_var.h
@@ -26,7 +26,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: md_var.h,v 1.16 1997/08/09 00:03:14 dyson Exp $
+ * $Id: md_var.h,v 1.17 1997/09/10 12:31:36 joerg Exp $
*/
#ifndef _MACHINE_MD_VAR_H_
@@ -68,7 +68,7 @@ void doreti_popl_es __P((void)) __asm(__STRING(doreti_popl_es));
void doreti_popl_es_fault __P((void)) __asm(__STRING(doreti_popl_es_fault));
int fill_regs __P((struct proc *p, struct reg *regs));
void fillw __P((int /*u_short*/ pat, void *base, size_t cnt));
-int is_adapter_memory __P((vm_offset_t addr));
+int is_physical_memory __P((vm_offset_t addr));
u_long kvtop __P((void *addr));
void setidt __P((int idx, alias_for_inthand_t *func, int typ, int dpl,
int selec));
OpenPOWER on IntegriCloud
diff --git a/sys/amd64/amd64/vm_machdep.c b/sys/amd64/amd64/vm_machdep.c
index dcb2a9a..01ad04a 100644
--- a/sys/amd64/amd64/vm_machdep.c
+++ b/sys/amd64/amd64/vm_machdep.c
@@ -38,7 +38,7 @@
*
* from: @(#)vm_machdep.c 7.3 (Berkeley) 5/13/91
* Utah $Hdr: vm_machdep.c 1.16.1.1 89/06/23$
- * $Id: vm_machdep.c,v 1.87 1997/09/02 20:05:31 bde Exp $
+ * $Id: vm_machdep.c,v 1.88 1997/09/10 12:31:28 joerg Exp $
*/
#include "npx.h"
@@ -959,7 +959,7 @@ vm_page_zero_idle()
}
/*
* Tell whether this address is in some adapter memory region.
* Currently used by the kernel coredump code in order to avoid
* dumping the ``ISA memory hole'' which could cause indefinite hangs,
* or other unpredictable behaviour.
@@ -968,14 +968,14 @@ vm_page_zero_idle()
#include "isa.h"
int
-is_adapter_memory(addr)
+is_physical_memory(addr)
vm_offset_t addr;
{
#if NISA > 0
/* The ISA ``memory hole''. */
if (addr >= 0xa0000 && addr < 0x100000)
- return 1;
+ return 0;
#endif
/*
@@ -983,5 +983,5 @@ is_adapter_memory(addr)
* here
*/
- return 0;
+ return 1;
}
@@ -959,7 +959,7 @@ vm_page_zero_idle()
}
/*
- * Tell whether this address is in some adapter memory region.
+ * Tell whether this address is in some physical memory region.
* Currently used by the kernel coredump code in order to avoid
* dumping the ``ISA memory hole'' which could cause indefinite hangs,